==> hslua-cli-1.4.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/hslua-cli.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-cli
version:              1.4.3
visibility:           public
id:                   hslua-cli-1.4.3-Fi00mFFmLpbcda1Vis0ze
key:                  hslua-cli-1.4.3-Fi00mFFmLpbcda1Vis0ze
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  b5c2049dc5802fcc4522dd56a18a0aac
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.3-Fi00mFFmLpbcda1Vis0ze
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-KVZAOBtyBRJJfQ9Z1lLe3O
    hslua-marshalling-2.3.1-AoiVt4uO5va6om9d9GjHrD
    hslua-repl-0.1.2-J0UrSmBbvg0EzZYXvs89XV
    lua-2.3.3-ELjw8zK7pFtHRKODFiJpGG text-2.0.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hslua-cli-1.4.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/hslua-cli.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-cli
version:              1.4.3
visibility:           public
id:                   hslua-cli-1.4.3-IQdcOWr9Fg5FNjQjmtS9Fb
key:                  hslua-cli-1.4.3-IQdcOWr9Fg5FNjQjmtS9Fb
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  29f3594070b4663f1ba7ccd9fd1dfc4b
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.3-IQdcOWr9Fg5FNjQjmtS9Fb
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-wqNpv1FfejBfZCMsG1pOG
    hslua-marshalling-2.3.1-7j5vE4T7F2E7P0F9J8JuVY
    hslua-repl-0.1.2-E51bWwXl6j3AxVQEPAhB8v
    lua-2.3.3-Ly6tkILeaJ5F6GNv7CwJkn text-2.0.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
